remote

Attribute Macro remote 

#[remote]
Available on crate feature derive only.
Attribute macro applies to the impl Actor for MyActor block, which overrides the internal method Actor::remote_mailbox to return a RemoteMailbox for a remote addressable actor.

This is a temporary workaround since specialization is not yet stable in Rust.

Example

use acktor_derive::remote;

#[remote]
impl Actor for MyActor {
    type Error = anyhow::Error;
    type Context = Context<Self>;
}