pub struct MessageCodec {
pub message_id: u64,
pub encode_msg: fn(&(dyn Any + 'static), Option<&dyn EncodeContext>) -> Result<Bytes, EncodeError>,
pub decode_res: fn(Bytes, Option<&dyn DecodeContext>) -> Result<Box<dyn Any>, DecodeError>,
}Expand description
A codec for a specific message type, containing the message id
(MessageId::ID), an EncodeMsgFn for encoding the message
to bytes, and a DecodeResFn for decoding the message response bytes back to the concrete
message response type.
Fields
message_id: u64encode_msg: fn(&(dyn Any + 'static), Option<&dyn EncodeContext>) -> Result<Bytes, EncodeError>decode_res: fn(Bytes, Option<&dyn DecodeContext>) -> Result<Box<dyn Any>, DecodeError>Trait Implementations
Sourceimpl Clone for MessageCodec
impl Clone for MessageCodec
Sourcefn clone(&self) -> MessageCodec
fn clone(&self) -> MessageCodec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MessageCodec