Entry

Enum Entry 

pub enum Entry<'a, K1, K2, V> {
    Occupied(OccupiedEntry<'a, K1, K2, V>),
    Vacant(VacantEntry<'a, K1, K2, V>),
}
A view into a single entry in a DoubleMap, which may be either vacant or occupied.

Variants



Occupied(OccupiedEntry<'a, K1, K2, V>)

Both provided keys identify the same existing entry.



Vacant(VacantEntry<'a, K1, K2, V>)

Neither of the provided keys is present — a new entry can be inserted.

Implementations

Source

impl<K1, K2, V> Entry<'_, K1, K2, V>

pub fn key1(&self) -> &K1

Returns a reference to the K1 key of this entry.

pub fn key2(&self) -> &K2

Returns a reference to the K2 key of this entry.

pub fn keys(&self) -> (&K1, &K2)

Returns a reference to the keys of type K1 and K2 of this entry.

Source

impl<'a, K1, K2, V> Entry<'a, K1, K2, V>
where K1: Clone, K2: Clone,

pub fn or_insert(self, default: V) -> &'a mut V

Ensures a value is in the entry by inserting default if vacant, and returns a mutable reference to the value.

pub fn or_insert_with<F>(self, default: F) -> &'a mut V
where F: FnOnce() -> V,

Ensures a value is in the entry by inserting the result of default if vacant, and returns a mutable reference to the value.

pub fn or_insert_with_keys<F>(self, default: F) -> &'a mut V
where F: FnOnce(&K1, &K2) -> V,

Ensures a value is in the entry by inserting the result of default if vacant, and returns a mutable reference to the value. The default closure receives references to the keys of the entry.

pub fn and_modify<F>(self, f: F) -> Self
where F: FnOnce(&mut V),

Provides in-place mutation of an occupied entry before any potential insertion, then returns the entry unchanged for further chaining.

pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K1, K2, V>

Sets the value of the entry, and returns an OccupiedEntry.

pub fn or_default(self) -> &'a mut V
where V: Default,

Ensures a value is in the entry by inserting the default value if vacant.