pub struct VacantEntry<'a, K1, K2, V> { /* private fields */ }Expand description
A view into a vacant entry of a DoubleMap.
Implementations
Sourceimpl<K1, K2, V> VacantEntry<'_, K1, K2, V>
impl<K1, K2, V> VacantEntry<'_, K1, K2, V>
Sourceimpl<'a, K1, K2, V> VacantEntry<'a, K1, K2, V>
impl<'a, K1, K2, V> VacantEntry<'a, K1, K2, V>
Sourcepub fn insert(self, value: V) -> &'a mut V
pub fn insert(self, value: V) -> &'a mut V
Sets the value of the entry with the VacantEntry’s key, and returns a mutable reference to it.
Sourcepub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K1, K2, V>
pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K1, K2, V>
Sets the value of the entry with the VacantEntry’s key, and returns an OccupiedEntry.