Module pipe

Module pipe 

Available on crate feature pipe only.
IPC method implementation using Unix domain sockets and Windows named pipes.

Structs

PipeConnection
IPC connection implemented with Unix domain sockets and Windows named pipes.
PipeListener
IPC listener implemented with Unix domain sockets and Windows named pipes.