Module node

Module node 

Node actor for managing IPC connections and sessions.

Modules

command
Commands which can be used to interact with a node.

Structs

Node
An actor which helps to manage the IPC connections.

Enums

NodeEvent
A message which is used to notify the receiver of an IPC session is created or deleted.