pub struct AddActor<A>where
A: Actor + RemoteAddressable,{
pub label: String,
pub address: Address<A>,
/* private fields */
}Expand description
A command which is used to add a remote addressable actor to a node.
The label is registered alongside the address so the actor can later be looked up by label
from a remote node. Returns false if either the label or the actor is already registered.
Fields
label: Stringaddress: Address<A>Implementations