Connect

Struct Connect 

pub struct Connect<C>
where C: IpcConnection,
{ pub endpoint: String, pub session_label: Option<String>, /* private fields */ }
A command which is used to actively connect to another node like a client.

A new session will be created if the operation is successful. The user can provide a session_label as an alias to the session, and it can be used to refer to the session actor in other commands. If session_label is not provided, the endpoint of the connection will be used as the alias of the new session actor.

The command will return the address of the session actor if it succeeds.

Fields

endpoint: Stringsession_label: Option<String>

Implementations

Source

impl<C> Connect<C>
where C: IpcConnection,

pub fn new<S1, S2>(endpoint: S1, label: S2) -> Self
where S1: AsRef<str>, S2: AsRef<str>,

Constructs a new Connect command for the connection type C.

pub fn no_label<S>(endpoint: S) -> Self
where S: AsRef<str>,

Constructs a new Connect command for the connection type C without a session label.