CreateRemoteActor

Struct CreateRemoteActor 

pub struct CreateRemoteActor {
    pub session: SessionHandle,
    pub label: String,
    pub type: String,
    pub config: String,
}
A command which is used to create an actor in a remote node.

The remote node needs to know how to create the actor with the given type and config. If the operation is successful, the provided label will be used as the actor label of the new actor created in the remote node.

Fields

session: SessionHandlelabel: Stringtype: Stringconfig: String