pub struct GetRemoteActor {
pub session: SessionHandle,
pub actor: ActorHandle,
}Expand description
A command which is used to get the address of an actor in a remote node.
Fields
session: SessionHandleactor: ActorHandleTrait Implementations
Sourceimpl Debug for GetRemoteActor
impl Debug for GetRemoteActor
Sourceimpl Handler<GetRemoteActor> for Node
impl Handler<GetRemoteActor> for Node
Sourcetype Result = FutureMessageResult<GetRemoteActor>
type Result = FutureMessageResult<GetRemoteActor>
The return type of the handler, which must implement
MessageResponse.Sourceimpl Message for GetRemoteActor
impl Message for GetRemoteActor