RemoveActor

Struct RemoveActor 

pub struct RemoveActor(pub ActorRef);
A command which is used to remove an actor from a node.

The actor is identified by its index or label. Returns false if no actor is found.

Tuple Fields

0: ActorRef