Node

Struct Node 

pub struct Node { /* private fields */ }
An actor which helps to manage the IPC connections.

The node can hold multiple IpcListeners to accept incoming IPC connections on several endpoints in parallel. Outbound connections are initiated by sending a Connect<C> command.

Implementations

Source

impl Node

pub fn new() -> Self

Constructs a new Node.

pub fn with_listener<L>(self, listener: L) -> Self
where L: IpcListener,

Adds an IPC listener to the node.

If the node already has a listener listening on the same endpoint, the new listener will replace the existing one, since the node is not started yet when this method is available. Note this is not the same as the AddListener command, which will not replace the existing listener.

pub fn with_actor<A, S>(self, label: S, actor: Address<A>) -> Self
where A: Actor + RemoteAddressable, S: AsRef<str>,

Adds an remote addressable actor to the node.

It also registers a label for the actor so that remote actors can look it up by a more user-friendly name.

Duplicate actors and labels are silently skipped.

pub fn with_factory<A>(self) -> Self

Adds an remote spawnable actor factory to the node.

Remote nodes can create instances of this actor type by sending a CreateActor node command.