RemoteMessage

Struct RemoteMessage 

pub struct RemoteMessage {
    pub actor_id: u64,
    pub message_id: u64,
    pub message: Bytes,
    pub result_tx: Option<Sender<Bytes>>,
    pub decode_context: Option<DecodeContext>,
}
A unified remote message used for communication with remote actors.

This is used both for outbound messages (sent by an actor in the current process to an actor in a remote process through Session) and for inbound messages (received by a Session and forwarded to an actor in the current process for handling).

Fields

actor_id: u64message_id: u64message: Bytesresult_tx: Option<Sender<Bytes>>decode_context: Option<DecodeContext>

Implementations

Source

impl RemoteMessage

pub fn do_send(actor_id: u64, message_id: u64, message: Bytes) -> Self

Constructs a new RemoteMessage which does not expect a response.

pub fn send( actor_id: u64, message_id: u64, message: Bytes, tx: Sender<Bytes>, ) -> Self

Constructs a new RemoteMessage which expects a response.

pub fn with_context(self, context: DecodeContext) -> Self

Sets the decode context on this message.