Module command

Module command 

Commands which can be used to interact with a session.

Structs

RemoteCreateActor
A command which is used to create an actor in a remote node.
RemoteGetActor
A command which is used to get the address of an actor in a remote node.