pub struct CreateRemoteActor {
pub label: String,
pub type: String,
pub config: String,
}Expand description
A command which is used to create an actor in a remote node.
The remote node needs to know how to create the actor with the given type and config. If
the operation is successful, the provided label will be used as the actor label of the
new actor created in the remote node.
Fields
label: Stringtype: Stringconfig: StringTrait Implementations
Sourceimpl Debug for CreateRemoteActor
impl Debug for CreateRemoteActor
Sourceimpl Handler<CreateRemoteActor> for Session
impl Handler<CreateRemoteActor> for Session
Sourcetype Result = FutureMessageResult<CreateRemoteActor>
type Result = FutureMessageResult<CreateRemoteActor>
The return type of the handler, which must implement
MessageResponse.Sourceimpl Message for CreateRemoteActor
impl Message for CreateRemoteActor
Sourcetype Result = Result<RemoteAddress, SessionError>
type Result = Result<RemoteAddress, SessionError>
The type of the response produced when this message is handled.