pub struct RemoteCreateActor<A>where
A: Actor + RemoteSpawnable,{
pub label: String,
pub config: Option<String>,
/* private fields */
}Expand description
A command which is used to create an actor in a remote node.
The actor type should have been registered in the remote node’s factory registry. If the
operation is successful, the provided label will be used as the actor label of the new actor
created in the remote node.
Fields
label: Stringconfig: Option<String>Implementations
Sourceimpl<A> RemoteCreateActor<A>where
A: Actor + RemoteSpawnable,
impl<A> RemoteCreateActor<A>where
A: Actor + RemoteSpawnable,