pub enum SessionHandle {
Address(Address<Session>),
Index(ActorId),
Label(String),
}Expand description
A session handle which can be used to identify a session in a node by either its actor address, index, or label.
Variants