pub struct DecodeContext { /* private fields */ }Expand description
Context passed through every Decode::decode call.
Carries the IPC session actor address and the remote actor registry which are needed to
reconstruct RemoteAddresss during decoding.
Implementations
Sourceimpl DecodeContext
impl DecodeContext
Sourcepub fn new(session: Address<Session>, registry: RemoteActorRegistry) -> Self
pub fn new(session: Address<Session>, registry: RemoteActorRegistry) -> Self
Constructs a new DecodeContext from the given remote session and the actor registry.
Sourcepub fn create_encode_context(&self) -> EncodeContext
pub fn create_encode_context(&self) -> EncodeContext
Creates a new EncodeContext from this context.
Sourcepub fn create_remote_address(
&self,
actor_id: u64,
) -> Result<RemoteAddress, DecodeError>
pub fn create_remote_address( &self, actor_id: u64, ) -> Result<RemoteAddress, DecodeError>
Creates a new RemoteAddress from the given actor ID.