pub struct EncodeContext { /* private fields */ }Expand description
Context passed through every Encode::encode call.
Carries the remote actor registry so that when the address of an actor which can be reached over IPC is serialized for the first time, it can self-register in the registry.
Implementations
Sourceimpl EncodeContext
impl EncodeContext
Sourcepub fn new(registry: RemoteActorRegistry) -> Self
pub fn new(registry: RemoteActorRegistry) -> Self
Constructs a new EncodeContext from the given actor registry.
Sourcepub fn create_decode_context(&self, session: Address<Session>) -> DecodeContext
pub fn create_decode_context(&self, session: Address<Session>) -> DecodeContext
Creates a new DecodeContext from this context and the given remote session.
Sourcepub fn register<A>(&self, address: &A) -> Result<(), EncodeError>where
A: SenderId + ToRemoteMessageRecipient,
pub fn register<A>(&self, address: &A) -> Result<(), EncodeError>where
A: SenderId + ToRemoteMessageRecipient,
Registers the given address/recipient in the actor registry.