RemoteSpawnable

Trait RemoteSpawnable 

pub trait RemoteSpawnable: RemoteAddressable + StableId {
    // Required method
    fn create_remote(
        label: String,
        config: String,
    ) -> Result<(Address<Self>, JoinHandle<()>), Self::Error>;
}
An actor type which can be created from another process.

Required Methods

fn create_remote( label: String, config: String, ) -> Result<(Address<Self>, JoinHandle<()>), Self::Error>

Creates an instance of this actor with the given label and config string.

Implementations typically call Actor::start or Actor::create internally.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors