Crate acktor_ipc

Crate acktor_ipc 

Re-exports

pub use errors::NodeError;
pub use errors::SessionError;
pub use ipc_method::IpcConnection;
pub use ipc_method::IpcListener;
pub use remote_actor::RemoteActor;
pub use remote_actor::RemoteActorFactory;
pub use node::Node;
pub use node::NodeEvent;
pub use session::Session;
pub use remote_message::RemoteMessage;
pub use acktor_ipc_proto as proto;

Modules

double_map
A map-like container supporting lookup by two independent key types.
errors
Error types used by this crate.
ipc_method
Traits for Inter-Process Communication (IPC) and some pre-implemented IPC methods.
node
Node actor for managing IPC connections and sessions.
remote_actor
Traits for actors which can be reached over IPC and a registry of this kind of actors.
remote_message
Remote message which can be sent over an IPC channel.
session
Per-connection session actor.

Structs

DecodeContext
Context passed through every Decode::decode call.
EncodeContext
Context passed through every Encode::encode call.
RemoteAddress
A type which is used to send messages to a remote actor.

Enums

ActorHandle
An actor handle which can be used to identify an actor in a node by either its index or label.

Traits

Decode
Describes how to decode a remote message.
Encode
Describes how to encode a remote message.

Attribute Macros

remotederive
Attribute macro applies to the impl Actor for MyActor { ... } block, which overrides the Actor::type_erased_recipient_fn used by acktor-ipc with a custom implementation that converts Address<Self> to Recipient<RemoteMessage> first and then erases the type.

Derive Macros

Decodederive
Derive the Decode trait for a message.
Encodederive
Derive the Encode trait for a message.
RemoteActorderive
Derive the RemoteActor trait for an actor.