Re-exports
pub use errors::NodeError;pub use errors::SessionError;pub use ipc_method::IpcConnection;pub use ipc_method::IpcListener;pub use remote_actor::RemoteActor;pub use remote_actor::RemoteActorFactory;pub use node::Node;pub use node::NodeEvent;pub use session::Session;pub use remote_message::RemoteMessage;pub use acktor_ipc_proto as proto;
Modules
- double_
map - A map-like container supporting lookup by two independent key types.
- errors
- Error types used by this crate.
- ipc_
method - Traits for Inter-Process Communication (IPC) and some pre-implemented IPC methods.
- node
- Node actor for managing IPC connections and sessions.
- remote_
actor - Traits for actors which can be reached over IPC and a registry of this kind of actors.
- remote_
message - Remote message which can be sent over an IPC channel.
- session
- Per-connection session actor.
Structs
- Decode
Context - Context passed through every
Decode::decodecall. - Encode
Context - Context passed through every
Encode::encodecall. - Remote
Address - A type which is used to send messages to a remote actor.
Enums
- Actor
Handle - An actor handle which can be used to identify an actor in a node by either its index or label.
Traits
Attribute Macros
- remote
derive - Attribute macro applies to the
impl Actor for MyActor { ... }block, which overrides theActor::type_erased_recipient_fnused byacktor-ipcwith a custom implementation that convertsAddress<Self>toRecipient<RemoteMessage>first and then erases the type.
Derive Macros
- Decode
derive - Derive the
Decodetrait for a message. - Encode
derive - Derive the
Encodetrait for a message. - Remote
Actor derive - Derive the
RemoteActortrait for an actor.