Commands which can be used to interact with a node.
Structs
- AddActor
- A command which is used to add an actor to a node.
- AddListener
- A command which is used to add an IPC listener to a node.
- Connect
- A command which is used by a node to actively connect to another node like a client.
- Create
Remote Actor - A command which is used to create an actor in a remote node.
- GetRemote
Actor - A command which is used to get the address of an actor in a remote node.
- Remove
Actor - A command which is used to remove an actor from a node.
- Remove
Listener - A command which is used to remove an IPC listener from a node.