pub struct Connect<C>where
C: IpcConnection,{
pub endpoint: String,
pub session_label: Option<String>,
/* private fields */
}Expand description
A command which is used to actively connect to another node like a client.
A new session will be created if the operation is successful. The user can provide a
session_label as an alias to the session, and it can be used to refer to the session actor
in other commands. If session_label is not provided, the endpoint of the connection will be
used as the alias of the new session actor.
The command will return the address of the session actor if it succeeds.
Fields
endpoint: Stringsession_label: Option<String>Implementations