pub struct Connect<C>where
C: IpcConnection,{
pub endpoint: String,
pub session_label: Option<String>,
pub _phantom: PhantomData<fn() -> C>,
}Expand description
A command which is used by a node to actively connect to another node like a client.
A new session will be created if the operation is successful. The endpoint of the connection
will be used as the actor label of the new session actor. The user can provide a
session_label as an alias to the endpoint, both labels can be used to refer to the session
actor in the other commands.
The command will return the address if it succeeds, however users are not recommended to await
the result. The recommended way is to listen to the
NodeEvent::SessionCreated event which is emitted
when a session is created, and get the session address from the event.
Fields
endpoint: Stringsession_label: Option<String>_phantom: PhantomData<fn() -> C>Implementations