pub struct RemoveActor(pub ActorRef);Expand description
A command which is used to remove an actor from a node.
The actor is identified by its index or label. Returns false if no actor is found.
Tuple Fields
0: ActorRefTrait Implementations
Sourceimpl Debug for RemoveActor
impl Debug for RemoveActor
Sourceimpl Handler<RemoveActor> for Node
impl Handler<RemoveActor> for Node