pub struct Node { /* private fields */ }Expand description
An actor which helps to manage the IPC connections.
The node can hold multiple IpcListeners to accept incoming IPC connections on several
endpoints in parallel. Outbound connections are initiated by sending a
Connect<C> command.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn with_listener<L>(self, listener: L) -> Selfwhere
L: IpcListener,
pub fn with_listener<L>(self, listener: L) -> Selfwhere
L: IpcListener,
Adds an IPC listener to the node.
If the node already has a listener listening on the same endpoint, the new listener will
replace the existing one. Note this is not the same as the
AddListener command, which will not replace the existing
listener.
Sourcepub fn with_actor<A>(self, actor: Address<A>) -> Selfwhere
A: RemoteActor,
pub fn with_actor<A>(self, actor: Address<A>) -> Selfwhere
A: RemoteActor,
Adds an actor which implements RemoteActor trait to the node.
Sourcepub fn with_actor_factory<A>(self) -> Selfwhere
A: RemoteActorFactory,
pub fn with_actor_factory<A>(self) -> Selfwhere
A: RemoteActorFactory,
Adds an actor factory so that remote peers can create instances of A by sending a
CreateActor node command to this node.