Commands which can be used to interact with a session.
Structs
- Remote
Create Actor - A command which is used to create an actor in a remote node.
- Remote
GetActor - A command which is used to get the address of an actor in a remote node.