Commands which can be used to interact with a session.
Structs
- Create
Remote Actor - A command which is used to create an actor in a remote node.
- GetRemote
Actor - A command which is used to get the address of an actor in a remote node.