RemoteCreateActor

Struct RemoteCreateActor 

pub struct RemoteCreateActor<A>{
    pub label: String,
    pub config: Option<String>,
    /* private fields */
}
A command which is used to create an actor in a remote node.

The actor type should have been registered in the remote node’s factory registry. If the operation is successful, the provided label will be used as the actor label of the new actor created in the remote node.

Fields

label: Stringconfig: Option<String>

Implementations

Source

impl<A> RemoteCreateActor<A>

pub fn new<S>(label: S, config: Option<String>) -> Self
where S: AsRef<str>,

Constructs a new RemoteCreateActor command for the actor type A.