pub struct RemoteAddress { /* private fields */ }Expand description
A type which is used to send messages to a remote actor.
Sender trait is implemented for this type, so it can be converted into a Recipient
type easily. This will allow us to store a remote address in the same place as a locals
address, and send messages with it without caring about the underlying transport details.
NOTE: user should not send a received RemoteAddress to another remote actor,
it is considered as a meaningless operation.
Implementations
Sourceimpl RemoteAddress
impl RemoteAddress
Sourcepub const REMOTE_FLAG: u64
pub const REMOTE_FLAG: u64
High bit of the 64-bit id space, reserved to tag a SenderId::index value as
remote address.
Sourcepub fn new(
remote_actor_id: u64,
session: Address<Session>,
registry: RemoteActorRegistry,
) -> Self
pub fn new( remote_actor_id: u64, session: Address<Session>, registry: RemoteActorRegistry, ) -> Self
Constructs a new RemoteAddress with the specified remote actor index and the address
of the IPC connection session actor. The registry is used to construct the encode
context for this address.
The index is computed by reversing the bits of session.index() into bits 0..62 (small
session ids occupy the high bits, growing downward) and XORing with remote_actor_id
(small ids occupy the low bits, growing upward). Bit 63 is reserved for
REMOTE_FLAG.
The collision of the index is structurally possible but extremely unlikely in practice
since it requires remote_actor_id * session.index() > 2^63.